embassy-stm32

Crates

git

Versions

stm32u585oi

Flavors

Fmc

Struct Fmc 

pub struct Fmc<'d, T: Instance> { /* private fields */ }
FMC driver

Implementations

Source

impl<'d, T> Fmc<'d, T>
where T: Instance,

pub fn new_raw(_instance: Peri<'d, T>) -> Self

Create a raw FMC instance.

Note: This is currently used to provide access to some basic FMC functions for manual configuration for memory types that stm32-fmc does not support.

pub fn enable(&mut self)

Enable the FMC peripheral and reset it.

pub fn memory_controller_enable(&mut self)

Enable the memory controller on applicable chips.

pub fn source_clock_hz(&self) -> u32

Get the kernel clock currently in use for this FMC instance.